==> xoonips-3.47.tar.gz: xoonips-3.47/itemtypes/xnpmodel/language/japanese/modinfo.php <==
<?php
// $Revision: 1.1.8.2 $
// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 * $Revision: 1.1.8.2 $
 */

// _MI_<MODULENAME>_<STRINGNAME>

// The name of this module
define("_MI_XNPMODEL_NAME","XooNIps Model Item Type Module");
// A brief description of this module
define("_MI_XNPMODEL_DESC","XooNIps Model Item Type Module");

// Names of admin menu items
define("_MI_XNPMODEL_CFG_DL_LIMIT","ϿԤˤ󥪥ץѤĤޤ");
define("_MI_XNPMODEL_CFG_DL_LIMIT_DESC","");

?>

==> xoonips-3.50.tar.gz: xoonips-3.50/itemtypes/xnpmodel/language/japanese/modinfo.php <==
<?php

// ------------------------------------------------------------------------- //
//  XooNIps - Neuroinformatics Base Platform System                          //
//  Copyright (C) 2005-2011 RIKEN, Japan All rights reserved.                //
//  http://xoonips.sourceforge.jp/                                           //
// ------------------------------------------------------------------------- //
//  This program is free software; you can redistribute it and/or modify     //
//  it under the terms of the GNU General Public License as published by     //
//  the Free Software Foundation; either version 2 of the License, or        //
//  (at your option) any later version.                                      //
//                                                                           //
//  You may not change or alter any portion of this comment or credits       //
//  of supporting developers from this source code or any supporting         //
//  source code which is considered copyrighted (c) material of the          //
//  original comment or credit authors.                                      //
//                                                                           //
//  This program is distributed in the hope that it will be useful,          //
//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
//  GNU General Public License for more details.                             //
//                                                                           //
//  You should have received a copy of the GNU General Public License        //
//  along with this program; if not, write to the Free Software              //
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
// ------------------------------------------------------------------------- //
/* constant strings
 */

// _MI_<MODULENAME>_<STRINGNAME>

// The name of this module
define('_MI_XNPMODEL_NAME', 'XooNIps Model Item Type Module');
// A brief description of this module
define('_MI_XNPMODEL_DESC', 'XooNIps Model Item Type Module');

// Names of admin menu items
define('_MI_XNPMODEL_CFG_DL_LIMIT', 'ϿԤˤ󥪥ץѤĤޤ');
define('_MI_XNPMODEL_CFG_DL_LIMIT_DESC', '');
